/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A;
typedef struct tySequence__WPcy3bORPBFlmk2KIq2pbQ tySequence__WPcy3bORPBFlmk2KIq2pbQ;
typedef struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA tyTuple__a1QJSSO0LTGR9bFH59c2xGCA;

/* section: NIM_merge_TYPES */
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A {
tySequence__WPcy3bORPBFlmk2KIq2pbQ* data;
NI counter;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__WPcy3bORPBFlmk2KIq2pbQ {
  TGenericSeq Sup;
  tyTuple__a1QJSSO0LTGR9bFH59c2xGCA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__4eRCaZmrYLLw2k30GPTiMw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, init__yuYJ6k5D1l1c5lO0bWkT5w)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg* s, NI initialSize);
static N_INLINE(NI, slotsNeeded__0mFDDY9ap9bzokRcevucuwRwsets)(NI count);
N_LIB_PRIVATE N_NIMCALL(NI, nextPowerOfTwo__v2qC0V55wqa9bmqc7eHTz8A)(NI x);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
static N_INLINE(NI, rawGet__h9bD59bk9aSaP9ae9axJ475zaRgsets)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg t, NimStringDesc* key, NI* hc);
N_LIB_PRIVATE N_NIMCALL(NI, hash__6PCYkKlCNhq9cnRLnqWKkwQ)(NimStringDesc* x);
static N_INLINE(NIM_BOOL, isFilled__uHIMxs9aGYDEfZheaMnN2sQsets)(NI hcode);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(NI, nextTry__YQqpuaZxbzuIDQ5oZ9bnvuQsets)(NI h, NI maxHash);
static N_INLINE(NIM_BOOL, mustRehash__9aQKy8l9bO9aHJHq2R79c0vEiAsets)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg t);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__S48V0eiEuyCalh7won1YWQ)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg* s);
static N_INLINE(NI, rawGetKnownHC__H4n01hI4Y1dhJhVV44eECQsets)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg t, NimStringDesc* key, NI hc);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__0WGPG59byJ2eMftxsrjD02A)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg* s, tySequence__4eRCaZmrYLLw2k30GPTiMw** data, NimStringDesc* key, NI hc, NI h);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_NIMCALL(void, Marker_tySequence__Bis5AbpONWcIRrPyPJS8Yw)(void* p, NI op);
static N_INLINE(NI, rawGet__Qz8z1q4s1IRE9bDLnTl4bbwsets)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w t, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI* hc);
N_LIB_PRIVATE N_NIMCALL(NI, hash__QVs9aU6P9bNaK5z46tImuY1A)(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___Zo7f0ykgAjRa3BqfD3izBw)(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ x, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y);
static N_INLINE(NIM_BOOL, mustRehash__7jWRj29cdORCgyfVVDoif0wsets)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w t);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__5AK1KndtgZOYfU62xezUug)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w* s);
static N_INLINE(NI, rawGetKnownHC__6QTj9a0w9a9bjoy9aqmJ9ae0smQsets)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w t, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI hc);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__5r6c062jDgID9ce2SRZQiTg)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w* s, tySequence__Bis5AbpONWcIRrPyPJS8Yw** data, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI hc, NI h);
static N_NIMCALL(void, Marker_tySequence__WPcy3bORPBFlmk2KIq2pbQ)(void* p, NI op);
static N_INLINE(NI, rawGet__UMO9cIGcjRdQju9cqT89a4Fegsets)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI* hc);
N_LIB_PRIVATE N_NIMCALL(NI, hash__XFPFecV5bGJUDhwku4bw7A)(tyArray__qtqsWM5aXmcpMIVmvq3kAA u);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___76rDYGuUQDl2xSav8vUDiA)(tyArray__qtqsWM5aXmcpMIVmvq3kAA a, tyArray__qtqsWM5aXmcpMIVmvq3kAA b);
static N_INLINE(NIM_BOOL, mustRehash__SkLBytF7aP9ajy2WDU8R9aYAsets)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A t);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__V1MJT9b2fqe4gEcAvgJR9brg)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A* s);
static N_INLINE(NI, rawGetKnownHC__qcToZ4y8o3WioWxmcVeLLwsets)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI hc);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__kd9ahbtKbkHSd9afyfGMxKSg)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A* s, tySequence__WPcy3bORPBFlmk2KIq2pbQ** data, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI hc, NI h);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);

/* section: NIM_merge_DATA */
N_LIB_PRIVATE TNimType NTI__CD8Dpv0WGmASelVaNSo6zg_;
N_LIB_PRIVATE TNimType NTI__QeWl6B6ffS4pU6WWrtcrDw_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTI__4eRCaZmrYLLw2k30GPTiMw_;
N_LIB_PRIVATE TNimType NTI__Gy4haGrophX9bC5RxnPAc6w_;
N_LIB_PRIVATE TNimType NTI__NAaJgGVgNmlGoqmiWxdOHQ_;
extern TNimType NTI__1v9bKyksXWMsm0vNwmZ4EuQ_;
N_LIB_PRIVATE TNimType NTI__Bis5AbpONWcIRrPyPJS8Yw_;
N_LIB_PRIVATE TNimType NTI__LWqBPbJi8sAUtgObUDu34A_;
N_LIB_PRIVATE TNimType NTI__a1QJSSO0LTGR9bFH59c2xGCA_;
extern TNimType NTI__qtqsWM5aXmcpMIVmvq3kAA_;
N_LIB_PRIVATE TNimType NTI__WPcy3bORPBFlmk2KIq2pbQ_;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tySequence__4eRCaZmrYLLw2k30GPTiMw)(void* p, NI op) {
	tySequence__4eRCaZmrYLLw2k30GPTiMw* a;
	NI T1_;
	a = (tySequence__4eRCaZmrYLLw2k30GPTiMw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_INLINE(NI, slotsNeeded__0mFDDY9ap9bzokRcevucuwRwsets)(NI count) {
	NI result;
	result = (NI)0;
	result = nextPowerOfTwo__v2qC0V55wqa9bmqc7eHTz8A((NI)((NI)((NI)(((NI) (count)) * ((NI) 3)) / ((NI) 2)) + ((NI) 4)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, init__yuYJ6k5D1l1c5lO0bWkT5w)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg* s, NI initialSize) {
	NI correctSizeX60gensym26_;
	correctSizeX60gensym26_ = slotsNeeded__0mFDDY9ap9bzokRcevucuwRwsets(((NI) (initialSize)));
	(*s).counter = ((NI) 0);
	unsureAsgnRef((void**) (&(*s).data), (tySequence__4eRCaZmrYLLw2k30GPTiMw*) newSeq((&NTI__4eRCaZmrYLLw2k30GPTiMw_), ((NI) (correctSizeX60gensym26_))));
}
N_LIB_PRIVATE N_NIMCALL(void, initHashSet__rR3V3EXK6m72GYtth8OqcA)(NI initialSize, tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg* Result) {
	unsureAsgnRef((void**)&(*Result).data, NIM_NIL);
	(*Result).counter = 0;
	init__yuYJ6k5D1l1c5lO0bWkT5w(Result, initialSize);
}
static N_INLINE(NIM_BOOL, isFilled__uHIMxs9aGYDEfZheaMnN2sQsets)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, nextTry__YQqpuaZxbzuIDQ5oZ9bnvuQsets)(NI h, NI maxHash) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)(h + ((NI) 1)) & maxHash);
	return result;
}
static N_INLINE(NI, rawGet__h9bD59bk9aSaP9ae9axJ475zaRgsets)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg t, NimStringDesc* key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__6PCYkKlCNhq9cnRLnqWKkwQ(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__uHIMxs9aGYDEfZheaMnN2sQsets(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = eqStrings(t.data->data[h].Field1, key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__YQqpuaZxbzuIDQ5oZ9bnvuQsets(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__9aQKy8l9bO9aHJHq2R79c0vEiAsets)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T2_ * ((NI) 2)) < (NI)(t.counter * ((NI) 3)));
	if (T1_) goto LA3_;
	T4_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T4_ - t.counter) < ((NI) 4));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGetKnownHC__H4n01hI4Y1dhJhVV44eECQsets)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg t, NimStringDesc* key, NI hc) {
	NI result;
	NI h;
	NI T6_;
{	result = (NI)0;
	{
		NI T3_;
		T3_ = (t.data ? t.data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(hc & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__uHIMxs9aGYDEfZheaMnN2sQsets(t.data->data[h].Field0);
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t.data->data[h].Field0 == hc);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t.data->data[h].Field1, key);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = h;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__YQqpuaZxbzuIDQ5oZ9bnvuQsets(h, T16_);
		} LA8: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__0WGPG59byJ2eMftxsrjD02A)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg* s, tySequence__4eRCaZmrYLLw2k30GPTiMw** data, NimStringDesc* key, NI hc, NI h) {
	NimStringDesc* T6_;
	{
		NI T3_;
		NI correctSizeX60gensym37_;
		T3_ = ((*data) ? (*data)->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym37_ = slotsNeeded__0mFDDY9ap9bzokRcevucuwRwsets(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__4eRCaZmrYLLw2k30GPTiMw*) newSeq((&NTI__4eRCaZmrYLLw2k30GPTiMw_), ((NI) (correctSizeX60gensym37_))));
	}
	LA4_: ;
	T6_ = (NimStringDesc*)0;
	T6_ = (*data)->data[h].Field1; (*data)->data[h].Field1 = copyStringRC1(key);
	if (T6_) nimGCunrefNoCycle(T6_);
	(*data)->data[h].Field0 = hc;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__S48V0eiEuyCalh7won1YWQ)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg* s) {
	tySequence__4eRCaZmrYLLw2k30GPTiMw* n;
	NI T1_;
	tySequence__4eRCaZmrYLLw2k30GPTiMw* T2_;
	n = (tySequence__4eRCaZmrYLLw2k30GPTiMw*)0;
	T1_ = ((*s).data ? (*s).data->Sup.len : 0);
	n = (tySequence__4eRCaZmrYLLw2k30GPTiMw*) newSeq((&NTI__4eRCaZmrYLLw2k30GPTiMw_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	T2_ = (tySequence__4eRCaZmrYLLw2k30GPTiMw*)0;
	T2_ = (*s).data;
	unsureAsgnRef((void**) (&(*s).data), n);
	n = T2_;
	{
		NI i;
		NI colontmp_;
		NI T4_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T4_ = ((n ? n->Sup.len : 0)-1);
		colontmp_ = T4_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA6;
				i = res;
				{
					NIM_BOOL T9_;
					NI j;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__uHIMxs9aGYDEfZheaMnN2sQsets(n->data[i].Field0);
					if (!T9_) goto LA10_;
					T12_ = (NI)0;
					T12_ = rawGetKnownHC__H4n01hI4Y1dhJhVV44eECQsets((*s), n->data[i].Field1, n->data[i].Field0);
					j = (NI)(((NI) -1) - T12_);
					rawInsert__0WGPG59byJ2eMftxsrjD02A(s, (&(*s).data), n->data[i].Field1, n->data[i].Field0, j);
				}
				LA10_: ;
				res += ((NI) 1);
			} LA6: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, incl__TMNSyv4q8yRKlH5e1bO09cA)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg* s, NimStringDesc* key) {
	NI hc;
	NI index;
	{
		NI T3_;
		NI correctSizeX60gensym28_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym28_ = slotsNeeded__0mFDDY9ap9bzokRcevucuwRwsets(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__4eRCaZmrYLLw2k30GPTiMw*) newSeq((&NTI__4eRCaZmrYLLw2k30GPTiMw_), ((NI) (correctSizeX60gensym28_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__h9bD59bk9aSaP9ae9axJ475zaRgsets((*s), key, (&hc));
	{
		if (!(index < ((NI) 0))) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = mustRehash__9aQKy8l9bO9aHJHq2R79c0vEiAsets((*s));
			if (!T12_) goto LA13_;
			enlarge__S48V0eiEuyCalh7won1YWQ(s);
			index = rawGetKnownHC__H4n01hI4Y1dhJhVV44eECQsets((*s), key, hc);
		}
		LA13_: ;
		rawInsert__0WGPG59byJ2eMftxsrjD02A(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA8_: ;
}
static N_NIMCALL(void, Marker_tySequence__Bis5AbpONWcIRrPyPJS8Yw)(void* p, NI op) {
	tySequence__Bis5AbpONWcIRrPyPJS8Yw* a;
	NI T1_;
	a = (tySequence__Bis5AbpONWcIRrPyPJS8Yw*)p;
	T1_ = (NI)0;
}
static N_INLINE(NI, rawGet__Qz8z1q4s1IRE9bDLnTl4bbwsets)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w t, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__QVs9aU6P9bNaK5z46tImuY1A(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__uHIMxs9aGYDEfZheaMnN2sQsets(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = eqeq___Zo7f0ykgAjRa3BqfD3izBw(t.data->data[h].Field1, key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__YQqpuaZxbzuIDQ5oZ9bnvuQsets(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__59b0yGhHVwyyUm0ZIA71uAg)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w s, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key) {
	NIM_BOOL result;
	NI hc;
	NI index;
	result = (NIM_BOOL)0;
	hc = (NI)0;
	index = rawGet__Qz8z1q4s1IRE9bDLnTl4bbwsets(s, key, (&hc));
	result = (((NI) 0) <= index);
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__7jWRj29cdORCgyfVVDoif0wsets)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T2_ * ((NI) 2)) < (NI)(t.counter * ((NI) 3)));
	if (T1_) goto LA3_;
	T4_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T4_ - t.counter) < ((NI) 4));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGetKnownHC__6QTj9a0w9a9bjoy9aqmJ9ae0smQsets)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w t, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI hc) {
	NI result;
	NI h;
	NI T6_;
{	result = (NI)0;
	{
		NI T3_;
		T3_ = (t.data ? t.data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(hc & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__uHIMxs9aGYDEfZheaMnN2sQsets(t.data->data[h].Field0);
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t.data->data[h].Field0 == hc);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___Zo7f0ykgAjRa3BqfD3izBw(t.data->data[h].Field1, key);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = h;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__YQqpuaZxbzuIDQ5oZ9bnvuQsets(h, T16_);
		} LA8: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__5r6c062jDgID9ce2SRZQiTg)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w* s, tySequence__Bis5AbpONWcIRrPyPJS8Yw** data, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI hc, NI h) {
	{
		NI T3_;
		NI correctSizeX60gensym25_;
		T3_ = ((*data) ? (*data)->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym25_ = slotsNeeded__0mFDDY9ap9bzokRcevucuwRwsets(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__Bis5AbpONWcIRrPyPJS8Yw*) newSeq((&NTI__Bis5AbpONWcIRrPyPJS8Yw_), ((NI) (correctSizeX60gensym25_))));
	}
	LA4_: ;
	(*data)->data[h].Field1 = key;
	(*data)->data[h].Field0 = hc;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__5AK1KndtgZOYfU62xezUug)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w* s) {
	tySequence__Bis5AbpONWcIRrPyPJS8Yw* n;
	NI T1_;
	tySequence__Bis5AbpONWcIRrPyPJS8Yw* T2_;
	n = (tySequence__Bis5AbpONWcIRrPyPJS8Yw*)0;
	T1_ = ((*s).data ? (*s).data->Sup.len : 0);
	n = (tySequence__Bis5AbpONWcIRrPyPJS8Yw*) newSeq((&NTI__Bis5AbpONWcIRrPyPJS8Yw_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	T2_ = (tySequence__Bis5AbpONWcIRrPyPJS8Yw*)0;
	T2_ = (*s).data;
	unsureAsgnRef((void**) (&(*s).data), n);
	n = T2_;
	{
		NI i;
		NI colontmp_;
		NI T4_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T4_ = ((n ? n->Sup.len : 0)-1);
		colontmp_ = T4_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA6;
				i = res;
				{
					NIM_BOOL T9_;
					NI j;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__uHIMxs9aGYDEfZheaMnN2sQsets(n->data[i].Field0);
					if (!T9_) goto LA10_;
					T12_ = (NI)0;
					T12_ = rawGetKnownHC__6QTj9a0w9a9bjoy9aqmJ9ae0smQsets((*s), n->data[i].Field1, n->data[i].Field0);
					j = (NI)(((NI) -1) - T12_);
					rawInsert__5r6c062jDgID9ce2SRZQiTg(s, (&(*s).data), n->data[i].Field1, n->data[i].Field0, j);
				}
				LA10_: ;
				res += ((NI) 1);
			} LA6: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, incl__VbzzejD20xvEpoMVXAdTSA)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w* s, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key) {
	NI hc;
	NI index;
	{
		NI T3_;
		NI correctSizeX60gensym18_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym18_ = slotsNeeded__0mFDDY9ap9bzokRcevucuwRwsets(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__Bis5AbpONWcIRrPyPJS8Yw*) newSeq((&NTI__Bis5AbpONWcIRrPyPJS8Yw_), ((NI) (correctSizeX60gensym18_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__Qz8z1q4s1IRE9bDLnTl4bbwsets((*s), key, (&hc));
	{
		if (!(index < ((NI) 0))) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = mustRehash__7jWRj29cdORCgyfVVDoif0wsets((*s));
			if (!T12_) goto LA13_;
			enlarge__5AK1KndtgZOYfU62xezUug(s);
			index = rawGetKnownHC__6QTj9a0w9a9bjoy9aqmJ9ae0smQsets((*s), key, hc);
		}
		LA13_: ;
		rawInsert__5r6c062jDgID9ce2SRZQiTg(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA8_: ;
}
static N_NIMCALL(void, Marker_tySequence__WPcy3bORPBFlmk2KIq2pbQ)(void* p, NI op) {
	tySequence__WPcy3bORPBFlmk2KIq2pbQ* a;
	NI T1_;
	NI T2_;
	a = (tySequence__WPcy3bORPBFlmk2KIq2pbQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	T2_ = (NI)0;
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__RafAVeUVSno4B47UdPqNlg)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg s, NimStringDesc* key) {
	NIM_BOOL result;
	NI hc;
	NI index;
	result = (NIM_BOOL)0;
	hc = (NI)0;
	index = rawGet__h9bD59bk9aSaP9ae9axJ475zaRgsets(s, key, (&hc));
	result = (((NI) 0) <= index);
	return result;
}
static N_INLINE(NI, rawGet__UMO9cIGcjRdQju9cqT89a4Fegsets)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__XFPFecV5bGJUDhwku4bw7A(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__uHIMxs9aGYDEfZheaMnN2sQsets(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = eqeq___76rDYGuUQDl2xSav8vUDiA(t.data->data[h].Field1, key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__YQqpuaZxbzuIDQ5oZ9bnvuQsets(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__SkLBytF7aP9ajy2WDU8R9aYAsets)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T2_ * ((NI) 2)) < (NI)(t.counter * ((NI) 3)));
	if (T1_) goto LA3_;
	T4_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T4_ - t.counter) < ((NI) 4));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGetKnownHC__qcToZ4y8o3WioWxmcVeLLwsets)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI hc) {
	NI result;
	NI h;
	NI T6_;
{	result = (NI)0;
	{
		NI T3_;
		T3_ = (t.data ? t.data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(hc & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__uHIMxs9aGYDEfZheaMnN2sQsets(t.data->data[h].Field0);
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t.data->data[h].Field0 == hc);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___76rDYGuUQDl2xSav8vUDiA(t.data->data[h].Field1, key);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = h;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__YQqpuaZxbzuIDQ5oZ9bnvuQsets(h, T16_);
		} LA8: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__kd9ahbtKbkHSd9afyfGMxKSg)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A* s, tySequence__WPcy3bORPBFlmk2KIq2pbQ** data, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI hc, NI h) {
	{
		NI T3_;
		NI correctSizeX60gensym401_;
		T3_ = ((*data) ? (*data)->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym401_ = slotsNeeded__0mFDDY9ap9bzokRcevucuwRwsets(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__WPcy3bORPBFlmk2KIq2pbQ*) newSeq((&NTI__WPcy3bORPBFlmk2KIq2pbQ_), ((NI) (correctSizeX60gensym401_))));
	}
	LA4_: ;
	nimCopyMem((void*)(*data)->data[h].Field1, (NIM_CONST void*)key, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	(*data)->data[h].Field0 = hc;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__V1MJT9b2fqe4gEcAvgJR9brg)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A* s) {
	tySequence__WPcy3bORPBFlmk2KIq2pbQ* n;
	NI T1_;
	tySequence__WPcy3bORPBFlmk2KIq2pbQ* T2_;
	n = (tySequence__WPcy3bORPBFlmk2KIq2pbQ*)0;
	T1_ = ((*s).data ? (*s).data->Sup.len : 0);
	n = (tySequence__WPcy3bORPBFlmk2KIq2pbQ*) newSeq((&NTI__WPcy3bORPBFlmk2KIq2pbQ_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	T2_ = (tySequence__WPcy3bORPBFlmk2KIq2pbQ*)0;
	T2_ = (*s).data;
	unsureAsgnRef((void**) (&(*s).data), n);
	n = T2_;
	{
		NI i;
		NI colontmp_;
		NI T4_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T4_ = ((n ? n->Sup.len : 0)-1);
		colontmp_ = T4_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA6;
				i = res;
				{
					NIM_BOOL T9_;
					NI j;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__uHIMxs9aGYDEfZheaMnN2sQsets(n->data[i].Field0);
					if (!T9_) goto LA10_;
					T12_ = (NI)0;
					T12_ = rawGetKnownHC__qcToZ4y8o3WioWxmcVeLLwsets((*s), n->data[i].Field1, n->data[i].Field0);
					j = (NI)(((NI) -1) - T12_);
					rawInsert__kd9ahbtKbkHSd9afyfGMxKSg(s, (&(*s).data), n->data[i].Field1, n->data[i].Field0, j);
				}
				LA10_: ;
				res += ((NI) 1);
			} LA6: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__KCQ2E6mQfCiuCUy6v2RUPw)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA key) {
	NIM_BOOL result;
	NI hc;
	NI index;
	result = (NIM_BOOL)0;
	{
		NI T3_;
		NI correctSizeX60gensym392_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym392_ = slotsNeeded__0mFDDY9ap9bzokRcevucuwRwsets(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__WPcy3bORPBFlmk2KIq2pbQ*) newSeq((&NTI__WPcy3bORPBFlmk2KIq2pbQ_), ((NI) (correctSizeX60gensym392_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__UMO9cIGcjRdQju9cqT89a4Fegsets((*s), key, (&hc));
	{
		if (!(((NI) 0) <= index)) goto LA8_;
		result = NIM_TRUE;
	}
	goto LA6_;
	LA8_: ;
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = mustRehash__SkLBytF7aP9ajy2WDU8R9aYAsets((*s));
			if (!T13_) goto LA14_;
			enlarge__V1MJT9b2fqe4gEcAvgJR9brg(s);
			index = rawGetKnownHC__qcToZ4y8o3WioWxmcVeLLwsets((*s), key, hc);
		}
		LA14_: ;
		rawInsert__kd9ahbtKbkHSd9afyfGMxKSg(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, stdlib_setsDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__0JXiWyhP5OCO8jWMA6sb1w_2_2[2];
static TNimNode* TM__0JXiWyhP5OCO8jWMA6sb1w_3_2[2];
static TNimNode* TM__0JXiWyhP5OCO8jWMA6sb1w_4_2[2];
static TNimNode* TM__0JXiWyhP5OCO8jWMA6sb1w_5_2[2];
static TNimNode* TM__0JXiWyhP5OCO8jWMA6sb1w_6_2[2];
static TNimNode* TM__0JXiWyhP5OCO8jWMA6sb1w_7_2[2];
static TNimNode TM__0JXiWyhP5OCO8jWMA6sb1w_0[18];

/* section: NIM_merge_TYPE_INIT3 */
NTI__CD8Dpv0WGmASelVaNSo6zg_.size = sizeof(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg);
NTI__CD8Dpv0WGmASelVaNSo6zg_.align = NIM_ALIGNOF(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg);
NTI__CD8Dpv0WGmASelVaNSo6zg_.kind = 18;
NTI__CD8Dpv0WGmASelVaNSo6zg_.base = 0;
NTI__CD8Dpv0WGmASelVaNSo6zg_.flags = 2;
TM__0JXiWyhP5OCO8jWMA6sb1w_2_2[0] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[1];
NTI__QeWl6B6ffS4pU6WWrtcrDw_.size = sizeof(tyTuple__QeWl6B6ffS4pU6WWrtcrDw);
NTI__QeWl6B6ffS4pU6WWrtcrDw_.align = NIM_ALIGNOF(tyTuple__QeWl6B6ffS4pU6WWrtcrDw);
NTI__QeWl6B6ffS4pU6WWrtcrDw_.kind = 18;
NTI__QeWl6B6ffS4pU6WWrtcrDw_.base = 0;
NTI__QeWl6B6ffS4pU6WWrtcrDw_.flags = 2;
TM__0JXiWyhP5OCO8jWMA6sb1w_3_2[0] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[3];
TM__0JXiWyhP5OCO8jWMA6sb1w_0[3].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[3].offset = offsetof(tyTuple__QeWl6B6ffS4pU6WWrtcrDw, Field0);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[3].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[3].name = "Field0";
TM__0JXiWyhP5OCO8jWMA6sb1w_3_2[1] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[4];
TM__0JXiWyhP5OCO8jWMA6sb1w_0[4].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[4].offset = offsetof(tyTuple__QeWl6B6ffS4pU6WWrtcrDw, Field1);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[4].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[4].name = "Field1";
TM__0JXiWyhP5OCO8jWMA6sb1w_0[2].len = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[2].kind = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[2].sons = &TM__0JXiWyhP5OCO8jWMA6sb1w_3_2[0];
NTI__QeWl6B6ffS4pU6WWrtcrDw_.node = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[2];
NTI__4eRCaZmrYLLw2k30GPTiMw_.size = sizeof(tySequence__4eRCaZmrYLLw2k30GPTiMw*);
NTI__4eRCaZmrYLLw2k30GPTiMw_.align = NIM_ALIGNOF(tySequence__4eRCaZmrYLLw2k30GPTiMw*);
NTI__4eRCaZmrYLLw2k30GPTiMw_.kind = 24;
NTI__4eRCaZmrYLLw2k30GPTiMw_.base = (&NTI__QeWl6B6ffS4pU6WWrtcrDw_);
NTI__4eRCaZmrYLLw2k30GPTiMw_.flags = 2;
NTI__4eRCaZmrYLLw2k30GPTiMw_.marker = Marker_tySequence__4eRCaZmrYLLw2k30GPTiMw;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[1].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[1].offset = offsetof(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg, data);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[1].typ = (&NTI__4eRCaZmrYLLw2k30GPTiMw_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[1].name = "data";
TM__0JXiWyhP5OCO8jWMA6sb1w_2_2[1] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[5];
TM__0JXiWyhP5OCO8jWMA6sb1w_0[5].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[5].offset = offsetof(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg, counter);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[5].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[5].name = "counter";
TM__0JXiWyhP5OCO8jWMA6sb1w_0[0].len = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[0].kind = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[0].sons = &TM__0JXiWyhP5OCO8jWMA6sb1w_2_2[0];
NTI__CD8Dpv0WGmASelVaNSo6zg_.node = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[0];
NTI__Gy4haGrophX9bC5RxnPAc6w_.size = sizeof(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w);
NTI__Gy4haGrophX9bC5RxnPAc6w_.align = NIM_ALIGNOF(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w);
NTI__Gy4haGrophX9bC5RxnPAc6w_.kind = 18;
NTI__Gy4haGrophX9bC5RxnPAc6w_.base = 0;
NTI__Gy4haGrophX9bC5RxnPAc6w_.flags = 2;
TM__0JXiWyhP5OCO8jWMA6sb1w_4_2[0] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[7];
NTI__NAaJgGVgNmlGoqmiWxdOHQ_.size = sizeof(tyTuple__NAaJgGVgNmlGoqmiWxdOHQ);
NTI__NAaJgGVgNmlGoqmiWxdOHQ_.align = NIM_ALIGNOF(tyTuple__NAaJgGVgNmlGoqmiWxdOHQ);
NTI__NAaJgGVgNmlGoqmiWxdOHQ_.kind = 18;
NTI__NAaJgGVgNmlGoqmiWxdOHQ_.base = 0;
NTI__NAaJgGVgNmlGoqmiWxdOHQ_.flags = 3;
TM__0JXiWyhP5OCO8jWMA6sb1w_5_2[0] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[9];
TM__0JXiWyhP5OCO8jWMA6sb1w_0[9].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[9].offset = offsetof(tyTuple__NAaJgGVgNmlGoqmiWxdOHQ, Field0);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[9].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[9].name = "Field0";
TM__0JXiWyhP5OCO8jWMA6sb1w_5_2[1] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[10];
TM__0JXiWyhP5OCO8jWMA6sb1w_0[10].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[10].offset = offsetof(tyTuple__NAaJgGVgNmlGoqmiWxdOHQ, Field1);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[10].typ = (&NTI__1v9bKyksXWMsm0vNwmZ4EuQ_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[10].name = "Field1";
TM__0JXiWyhP5OCO8jWMA6sb1w_0[8].len = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[8].kind = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[8].sons = &TM__0JXiWyhP5OCO8jWMA6sb1w_5_2[0];
NTI__NAaJgGVgNmlGoqmiWxdOHQ_.node = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[8];
NTI__Bis5AbpONWcIRrPyPJS8Yw_.size = sizeof(tySequence__Bis5AbpONWcIRrPyPJS8Yw*);
NTI__Bis5AbpONWcIRrPyPJS8Yw_.align = NIM_ALIGNOF(tySequence__Bis5AbpONWcIRrPyPJS8Yw*);
NTI__Bis5AbpONWcIRrPyPJS8Yw_.kind = 24;
NTI__Bis5AbpONWcIRrPyPJS8Yw_.base = (&NTI__NAaJgGVgNmlGoqmiWxdOHQ_);
NTI__Bis5AbpONWcIRrPyPJS8Yw_.flags = 2;
NTI__Bis5AbpONWcIRrPyPJS8Yw_.marker = Marker_tySequence__Bis5AbpONWcIRrPyPJS8Yw;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[7].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[7].offset = offsetof(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w, data);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[7].typ = (&NTI__Bis5AbpONWcIRrPyPJS8Yw_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[7].name = "data";
TM__0JXiWyhP5OCO8jWMA6sb1w_4_2[1] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[11];
TM__0JXiWyhP5OCO8jWMA6sb1w_0[11].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[11].offset = offsetof(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w, counter);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[11].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[11].name = "counter";
TM__0JXiWyhP5OCO8jWMA6sb1w_0[6].len = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[6].kind = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[6].sons = &TM__0JXiWyhP5OCO8jWMA6sb1w_4_2[0];
NTI__Gy4haGrophX9bC5RxnPAc6w_.node = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[6];
NTI__LWqBPbJi8sAUtgObUDu34A_.size = sizeof(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A);
NTI__LWqBPbJi8sAUtgObUDu34A_.align = NIM_ALIGNOF(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A);
NTI__LWqBPbJi8sAUtgObUDu34A_.kind = 18;
NTI__LWqBPbJi8sAUtgObUDu34A_.base = 0;
NTI__LWqBPbJi8sAUtgObUDu34A_.flags = 2;
TM__0JXiWyhP5OCO8jWMA6sb1w_6_2[0] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[13];
NTI__a1QJSSO0LTGR9bFH59c2xGCA_.size = sizeof(tyTuple__a1QJSSO0LTGR9bFH59c2xGCA);
NTI__a1QJSSO0LTGR9bFH59c2xGCA_.align = NIM_ALIGNOF(tyTuple__a1QJSSO0LTGR9bFH59c2xGCA);
NTI__a1QJSSO0LTGR9bFH59c2xGCA_.kind = 18;
NTI__a1QJSSO0LTGR9bFH59c2xGCA_.base = 0;
NTI__a1QJSSO0LTGR9bFH59c2xGCA_.flags = 3;
TM__0JXiWyhP5OCO8jWMA6sb1w_7_2[0] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[15];
TM__0JXiWyhP5OCO8jWMA6sb1w_0[15].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[15].offset = offsetof(tyTuple__a1QJSSO0LTGR9bFH59c2xGCA, Field0);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[15].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[15].name = "Field0";
TM__0JXiWyhP5OCO8jWMA6sb1w_7_2[1] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[16];
TM__0JXiWyhP5OCO8jWMA6sb1w_0[16].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[16].offset = offsetof(tyTuple__a1QJSSO0LTGR9bFH59c2xGCA, Field1);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[16].typ = (&NTI__qtqsWM5aXmcpMIVmvq3kAA_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[16].name = "Field1";
TM__0JXiWyhP5OCO8jWMA6sb1w_0[14].len = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[14].kind = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[14].sons = &TM__0JXiWyhP5OCO8jWMA6sb1w_7_2[0];
NTI__a1QJSSO0LTGR9bFH59c2xGCA_.node = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[14];
NTI__WPcy3bORPBFlmk2KIq2pbQ_.size = sizeof(tySequence__WPcy3bORPBFlmk2KIq2pbQ*);
NTI__WPcy3bORPBFlmk2KIq2pbQ_.align = NIM_ALIGNOF(tySequence__WPcy3bORPBFlmk2KIq2pbQ*);
NTI__WPcy3bORPBFlmk2KIq2pbQ_.kind = 24;
NTI__WPcy3bORPBFlmk2KIq2pbQ_.base = (&NTI__a1QJSSO0LTGR9bFH59c2xGCA_);
NTI__WPcy3bORPBFlmk2KIq2pbQ_.flags = 2;
NTI__WPcy3bORPBFlmk2KIq2pbQ_.marker = Marker_tySequence__WPcy3bORPBFlmk2KIq2pbQ;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[13].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[13].offset = offsetof(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A, data);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[13].typ = (&NTI__WPcy3bORPBFlmk2KIq2pbQ_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[13].name = "data";
TM__0JXiWyhP5OCO8jWMA6sb1w_6_2[1] = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[17];
TM__0JXiWyhP5OCO8jWMA6sb1w_0[17].kind = 1;
TM__0JXiWyhP5OCO8jWMA6sb1w_0[17].offset = offsetof(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A, counter);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[17].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__0JXiWyhP5OCO8jWMA6sb1w_0[17].name = "counter";
TM__0JXiWyhP5OCO8jWMA6sb1w_0[12].len = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[12].kind = 2; TM__0JXiWyhP5OCO8jWMA6sb1w_0[12].sons = &TM__0JXiWyhP5OCO8jWMA6sb1w_6_2[0];
NTI__LWqBPbJi8sAUtgObUDu34A_.node = &TM__0JXiWyhP5OCO8jWMA6sb1w_0[12];
}

